@@ -28,7 +28,7 @@ WebWidget::WebWidget(QWidget *parent)
     layout->setContentsMargins({});
 
     mWebSiteEdit->setTrapReturnKey(true);
-    mWebSiteEdit->setPlaceholderText(i18n("Add a Web Site"));
+    mWebSiteEdit->setPlaceholderText(i18nc("@info:placeholder", "Add a Web Site"));
     mWebSiteEdit->setObjectName(QLatin1StringView("website"));
     layout->addWidget(mWebSiteEdit);
     connect(mWebSiteEdit, &PreferredLineEditWidget::preferredChanged, this, &WebWidget::slotPreferredChanged);
@@ -38,13 +38,13 @@ WebWidget::WebWidget(QWidget *parent)
 
     mAddButton->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     mAddButton->setObjectName(QLatin1StringView("addbutton"));
-    mAddButton->setToolTip(i18n("Add a Web Site"));
+    mAddButton->setToolTip(i18nc("@info:tooltip", "Add a Web Site"));
     connect(mAddButton, &QToolButton::clicked, this, &WebWidget::slotAddWeb);
     layout->addWidget(mAddButton);
 
     mRemoveButton->setObjectName(QLatin1StringView("removebutton"));
     mRemoveButton->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
-    mRemoveButton->setToolTip(i18n("Remove Web Site"));
+    mRemoveButton->setToolTip(i18nc("@info:tooltip", "Remove Web Site"));
     connect(mRemoveButton, &QToolButton::clicked, this, &WebWidget::slotRemoveWeb);
     layout->addWidget(mRemoveButton);
 }
